pub async fn dag_stat(cid_str: &str, format: &OutputFormat) -> Result<()>Expand description
Print DAG node stats: CID, size, links, codec.
This mirrors ipld_stat but is exposed under the dag command group.
pub async fn dag_stat(cid_str: &str, format: &OutputFormat) -> Result<()>Print DAG node stats: CID, size, links, codec.
This mirrors ipld_stat but is exposed under the dag command group.