semantic_query_with_cids

Function semantic_query_with_cids 

pub async fn semantic_query_with_cids(
    text: &str,
    top_k: usize,
    threshold: f32,
    json_output: bool,
) -> Result<Vec<String>>
Semantic similarity search that also returns the matching CIDs.

Used by the hybrid query pipeline so that logic post-filtering can be applied to the semantic result set without re-running the search.