check_daemon_reachable

Function check_daemon_reachable 

pub async fn check_daemon_reachable(data_dir: &str) -> bool
Check whether the IPFRS daemon is reachable.

Returns true if a running process with the recorded PID can be found, false in every other case (missing PID file, stale PID, parse error …).

The whole operation is designed to complete in well under DAEMON_CHECK_TIMEOUT.

Arguments

  • data_dir – Path to the IPFRS data directory that contains daemon.pid (e.g. .ipfrs).