pub async fn logic_filter(
predicate_template: &str,
json_output: bool,
data_dir: &str,
) -> Result<()>Expand description
Read CIDs from stdin and filter by logic predicate.
Each non-empty line on stdin is treated as a CID. The predicate template
uses X as a placeholder that is replaced by the CID before inference.
Example
echo "bafkrei123" | ipfrs logic filter "indexed(X)"