pub struct Config {
pub general: GeneralConfig,
pub storage: StorageConfig,
pub network: NetworkConfig,
pub gateway: GatewayConfig,
pub api: ApiConfig,
pub shell: ShellConfig,
}Expand description
Main configuration structure
Fields
general: GeneralConfigGeneral settings
storage: StorageConfigStorage settings
network: NetworkConfigNetwork settings
gateway: GatewayConfigGateway settings
api: ApiConfigAPI settings
shell: ShellConfigShell settings
Implementations
Sourceimpl Config
impl Config
Sourcepub fn load() -> Result<Self>
pub fn load() -> Result<Self>
Load configuration from default locations (with caching)
This method uses a global cache to avoid repeated disk reads. The config is loaded once and reused for subsequent calls.
Search order:
- .ipfrs/config.toml (current directory)
- ~/.ipfrs/config.toml (user home)
- /etc/ipfrs/config.toml (system)
Sourcepub fn load_uncached() -> Result<Self>
pub fn load_uncached() -> Result<Self>
Load configuration from default locations without caching
Use this when you need to force a fresh load (e.g., after config changes).
Search order:
- .ipfrs/config.toml (current directory)
- ~/.ipfrs/config.toml (user home)
- /etc/ipfrs/config.toml (system)
Environment variables (override config file):
- IPFRS_PATH: Data directory
- IPFRS_LOG_LEVEL: Log level
- IPFRS_API_URL: Remote API URL
- IPFRS_API_TOKEN: API authentication token
Sourcepub fn api_url(&self) -> String
pub fn api_url(&self) -> String
Get the effective API URL
Returns the remote URL if set, otherwise returns the local listen address formatted as http://address
Sourcepub fn clear_cache()
pub fn clear_cache()
Clear the cached configuration
This forces the next load() call to reload from disk.
Note: Due to OnceLock limitations, this doesn’t actually clear the cache
but is provided for API consistency. Use load_uncached() instead.
Sourcepub fn default_path() -> Result<PathBuf>
pub fn default_path() -> Result<PathBuf>
Get the default configuration file path
Returns the path to the user’s configuration file (~/.ipfrs/config.toml)
Sourcepub fn generate_default_config() -> String
pub fn generate_default_config() -> String
Generate default config file with comments